@@ -86,7 +86,11 @@ class Disbursement:
             'Content-Type': 'application/json',
             'Authorization':  "Bearer " + str(self.authToken()["access_token"])
             }
-        response = requests.post(url, headers=headers, json=payload)
+        proxies = {
+            "http": os.environ.get('QUOTAGUARDSTATIC_URL'),
+            "https": os.environ.get('QUOTAGUARDSTATIC_URL')
+            }
+        response = requests.post(url, headers=headers, json=payload, proxies=proxies)
 
         if response.status_code == 200:
             return response.json()
@@ -108,7 +112,12 @@ class Disbursement:
             'Authorization':  "Bearer " + str(self.authToken()["access_token"])
         }
 
-        response = requests.request("GET", url, headers=headers, data=payload)
+        proxies = {
+            "http": os.environ.get('QUOTAGUARDSTATIC_URL'),
+            "https": os.environ.get('QUOTAGUARDSTATIC_URL')
+            }
+
+        response = requests.request("GET", url, headers=headers, data=payload, proxies=proxies)
         returneddata = response.json()
 
         res = {
